#include "preprocessorplugin.h"

#include "preprocessorview.h"

#include <KPluginFactory>
#include <KPluginLoader>
#include <KAboutData>
#include <KDebug>
#include <KActionCollection>
#include <KAction>
#include <KLocale>

K_PLUGIN_FACTORY (KdevPlugFactory, registerPlugin<PreprocessorPlugin>();)
K_EXPORT_PLUGIN (KdevPlugFactory (KAboutData ("Preprocessor","Preprocessor", ki18n ("Preprocess the Current File"), "0.1", ki18n ("Preprocess the Current File"), KAboutData::License_GPL)))

PreprocessorPlugin::PreprocessorPlugin (QObject *parent, const QVariantList &)
:IPlugin (KdevPlugFactory::componentData(), parent)
{
		setXMLFile ("kdevpreprocessor.rc");
		
		m_actionPreprocess = actionCollection()->addAction ("file_preprocess");
		m_actionPreprocess->setIcon (KIcon ("circle2"));
		m_actionPreprocess->setText (i18n ("Preprocess File"));
		m_actionPreprocess->setShortcut (KShortcut ("Ctrl+Alt+Shift+p"));
		connect (m_actionPreprocess, SIGNAL (triggered (bool)), this, SLOT (preprocess()));
		m_actionPreprocess->setToolTip (i18n ("Preprocess the Current File"));
		m_actionPreprocess->setWhatsThis (i18n ("<b>Preprocessor</b><p> View the preprocessor-ouput, the content of included files is not displayed"));
		
		m_actionPreprocessWithIncludes->setIcon (KIcon ("circle"));
		m_actionPreprocessWithIncludes->setText (i18n ("Preprocess File (with included content)"));
		connect (m_actionPreprocessWithIncludes, SIGNAL (triggered (bool)), this, SLOT (preprocessWithIncludes()));
		m_actionPreprocessWithIncludes->setToolTip (i18n ("Preprocess the Current File and Display the Content of Included Files"));
		m_actionPreprocessWithIncludes->setWhatsThis (i18n ("<b>Preprocessor</b><p> View the preprocessor-ouput, the content of included files is displayed"));
		
}

PreprocessorPlugin::~PreprocessorPlugin()
{
}

void PreprocessorPlugin::preprocess()
{
		new PreprocessorView(this, false);
}

void PreprocessorPlugin::preprocessWithIncludes()
{
		new PreprocessorView(this, true);
}

#include "preprocessorplugin.moc"
